==> huaweicloudsdkdds-3.0.49-py2.py3-none-any.whl: huaweicloudsdkdds/v3/model/list_sessions_request.py <==
# coding: utf-8

import pprint
import re

import six





class ListSessionsRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'node_id': 'str',
        'offset': 'int',
        'limit': 'int',
        'plan_summary': 'str',
        'type': 'str',
        'namespace': 'str',
        'cost_time': 'int'
    }

    attribute_map = {
        'node_id': 'node_id',
        'offset': 'offset',
        'limit': 'limit',
        'plan_summary': 'plan_summary',
        'type': 'type',
        'namespace': 'namespace',
        'cost_time': 'cost_time'
    }

    def __init__(self, node_id=None, offset=None, limit=None, plan_summary=None, type=None, namespace=None, cost_time=None):
        """ListSessionsRequest - a model defined in huaweicloud sdk"""
        
        

        self._node_id = None
        self._offset = None
        self._limit = None
        self._plan_summary = None
        self._type = None
        self._namespace = None
        self._cost_time = None
        self.discriminator = None

        self.node_id = node_id
        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit
        if plan_summary is not None:
            self.plan_summary = plan_summary
        if type is not None:
            self.type = type
        if namespace is not None:
            self.namespace = namespace
        if cost_time is not None:
            self.cost_time = cost_time

    @property
    def node_id(self):
        """Gets the node_id of this ListSessionsRequest.

        节点ID。允许查询的节点如下： 集群下面的 mongos节点以及 副本集、单节点实例下面的所有节点。

        :return: The node_id of this ListSessionsRequest.
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this ListSessionsRequest.

        节点ID。允许查询的节点如下： 集群下面的 mongos节点以及 副本集、单节点实例下面的所有节点。

        :param node_id: The node_id of this ListSessionsRequest.
        :type: str
        """
        self._node_id = node_id

    @property
    def offset(self):
        """Gets the offset of this ListSessionsRequest.

        索引位置，偏移量。 从第一条数据偏移offset条数据后开始查询，默认为0（偏移0条数据，表示从第一条数据开始查询），必须为数字，不能为负数。

        :return: The offset of this ListSessionsRequest.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this ListSessionsRequest.

        索引位置，偏移量。 从第一条数据偏移offset条数据后开始查询，默认为0（偏移0条数据，表示从第一条数据开始查询），必须为数字，不能为负数。

        :param offset: The offset of this ListSessionsRequest.
        :type: int
        """
        self._offset = offset

    @property
    def limit(self):
        """Gets the limit of this ListSessionsRequest.

        查询记录数。取值范围[1, 20]，默认10 （表示返回10条数据）。

        :return: The limit of this ListSessionsRequest.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this ListSessionsRequest.

        查询记录数。取值范围[1, 20]，默认10 （表示返回10条数据）。

        :param limit: The limit of this ListSessionsRequest.
        :type: int
        """
        self._limit = limit

    @property
    def plan_summary(self):
        """Gets the plan_summary of this ListSessionsRequest.

        执行计划描述。取空值表示查询所有语句类型，也可指定执行计划，例如： COLLSCAN IXSCAN FETCH SORT LIMIT SKIP COUNT COUNT_SCAN TEXT PROJECTION 等

        :return: The plan_summary of this ListSessionsRequest.
        :rtype: str
        """
        return self._plan_summary

    @plan_summary.setter
    def plan_summary(self, plan_summary):
        """Sets the plan_summary of this ListSessionsRequest.

        执行计划描述。取空值表示查询所有语句类型，也可指定执行计划，例如： COLLSCAN IXSCAN FETCH SORT LIMIT SKIP COUNT COUNT_SCAN TEXT PROJECTION 等

        :param plan_summary: The plan_summary of this ListSessionsRequest.
        :type: str
        """
        self._plan_summary = plan_summary

    @property
    def type(self):
        """Gets the type of this ListSessionsRequest.

        操作类型。取空值表示查询所有操作类型。也可指定操作类型，例如： none update insert query command getmore remove killcursors等

        :return: The type of this ListSessionsRequest.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ListSessionsRequest.

        操作类型。取空值表示查询所有操作类型。也可指定操作类型，例如： none update insert query command getmore remove killcursors等

        :param type: The type of this ListSessionsRequest.
        :type: str
        """
        self._type = type

    @property
    def namespace(self):
        """Gets the namespace of this ListSessionsRequest.

        命名空间。取空值表示查询所有命名空间。也可根据当前业务进行指定。

        :return: The namespace of this ListSessionsRequest.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this ListSessionsRequest.

        命名空间。取空值表示查询所有命名空间。也可根据当前业务进行指定。

        :param namespace: The namespace of this ListSessionsRequest.
        :type: str
        """
        self._namespace = namespace

    @property
    def cost_time(self):
        """Gets the cost_time of this ListSessionsRequest.

        运行时间，单位为 ms。取空值表示查询所有的运行时间。也可根据当前业务需要进行配置，表示查询超出 cost_time 的会话。

        :return: The cost_time of this ListSessionsRequest.
        :rtype: int
        """
        return self._cost_time

    @cost_time.setter
    def cost_time(self, cost_time):
        """Sets the cost_time of this ListSessionsRequest.

        运行时间，单位为 ms。取空值表示查询所有的运行时间。也可根据当前业务需要进行配置，表示查询超出 cost_time 的会话。

        :param cost_time: The cost_time of this ListSessionsRequest.
        :type: int
        """
        self._cost_time = cost_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListSessionsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdds-3.0.52-py2.py3-none-any.whl: huaweicloudsdkdds/v3/model/list_sessions_request.py <==
# coding: utf-8

import re
import six





class ListSessionsRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'node_id': 'str',
        'offset': 'int',
        'limit': 'int',
        'plan_summary': 'str',
        'type': 'str',
        'namespace': 'str',
        'cost_time': 'int'
    }

    attribute_map = {
        'node_id': 'node_id',
        'offset': 'offset',
        'limit': 'limit',
        'plan_summary': 'plan_summary',
        'type': 'type',
        'namespace': 'namespace',
        'cost_time': 'cost_time'
    }

    def __init__(self, node_id=None, offset=None, limit=None, plan_summary=None, type=None, namespace=None, cost_time=None):
        """ListSessionsRequest - a model defined in huaweicloud sdk"""
        
        

        self._node_id = None
        self._offset = None
        self._limit = None
        self._plan_summary = None
        self._type = None
        self._namespace = None
        self._cost_time = None
        self.discriminator = None

        self.node_id = node_id
        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit
        if plan_summary is not None:
            self.plan_summary = plan_summary
        if type is not None:
            self.type = type
        if namespace is not None:
            self.namespace = namespace
        if cost_time is not None:
            self.cost_time = cost_time

    @property
    def node_id(self):
        """Gets the node_id of this ListSessionsRequest.

        节点ID。允许查询的节点如下： 集群下面的 mongos节点以及 副本集、单节点实例下面的所有节点。

        :return: The node_id of this ListSessionsRequest.
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this ListSessionsRequest.

        节点ID。允许查询的节点如下： 集群下面的 mongos节点以及 副本集、单节点实例下面的所有节点。

        :param node_id: The node_id of this ListSessionsRequest.
        :type: str
        """
        self._node_id = node_id

    @property
    def offset(self):
        """Gets the offset of this ListSessionsRequest.

        索引位置，偏移量。 从第一条数据偏移offset条数据后开始查询，默认为0（偏移0条数据，表示从第一条数据开始查询），必须为数字，不能为负数。

        :return: The offset of this ListSessionsRequest.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this ListSessionsRequest.

        索引位置，偏移量。 从第一条数据偏移offset条数据后开始查询，默认为0（偏移0条数据，表示从第一条数据开始查询），必须为数字，不能为负数。

        :param offset: The offset of this ListSessionsRequest.
        :type: int
        """
        self._offset = offset

    @property
    def limit(self):
        """Gets the limit of this ListSessionsRequest.

        查询记录数。取值范围[1, 20]，默认10 （表示返回10条数据）。

        :return: The limit of this ListSessionsRequest.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this ListSessionsRequest.

        查询记录数。取值范围[1, 20]，默认10 （表示返回10条数据）。

        :param limit: The limit of this ListSessionsRequest.
        :type: int
        """
        self._limit = limit

    @property
    def plan_summary(self):
        """Gets the plan_summary of this ListSessionsRequest.

        执行计划描述。取空值表示查询所有语句类型，也可指定执行计划，例如： COLLSCAN IXSCAN FETCH SORT LIMIT SKIP COUNT COUNT_SCAN TEXT PROJECTION 等

        :return: The plan_summary of this ListSessionsRequest.
        :rtype: str
        """
        return self._plan_summary

    @plan_summary.setter
    def plan_summary(self, plan_summary):
        """Sets the plan_summary of this ListSessionsRequest.

        执行计划描述。取空值表示查询所有语句类型，也可指定执行计划，例如： COLLSCAN IXSCAN FETCH SORT LIMIT SKIP COUNT COUNT_SCAN TEXT PROJECTION 等

        :param plan_summary: The plan_summary of this ListSessionsRequest.
        :type: str
        """
        self._plan_summary = plan_summary

    @property
    def type(self):
        """Gets the type of this ListSessionsRequest.

        操作类型。取空值表示查询所有操作类型。也可指定操作类型，例如： none update insert query command getmore remove killcursors等

        :return: The type of this ListSessionsRequest.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ListSessionsRequest.

        操作类型。取空值表示查询所有操作类型。也可指定操作类型，例如： none update insert query command getmore remove killcursors等

        :param type: The type of this ListSessionsRequest.
        :type: str
        """
        self._type = type

    @property
    def namespace(self):
        """Gets the namespace of this ListSessionsRequest.

        命名空间。取空值表示查询所有命名空间。也可根据当前业务进行指定。

        :return: The namespace of this ListSessionsRequest.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this ListSessionsRequest.

        命名空间。取空值表示查询所有命名空间。也可根据当前业务进行指定。

        :param namespace: The namespace of this ListSessionsRequest.
        :type: str
        """
        self._namespace = namespace

    @property
    def cost_time(self):
        """Gets the cost_time of this ListSessionsRequest.

        运行时间，单位为 ms。取空值表示查询所有的运行时间。也可根据当前业务需要进行配置，表示查询超出 cost_time 的会话。

        :return: The cost_time of this ListSessionsRequest.
        :rtype: int
        """
        return self._cost_time

    @cost_time.setter
    def cost_time(self, cost_time):
        """Sets the cost_time of this ListSessionsRequest.

        运行时间，单位为 ms。取空值表示查询所有的运行时间。也可根据当前业务需要进行配置，表示查询超出 cost_time 的会话。

        :param cost_time: The cost_time of this ListSessionsRequest.
        :type: int
        """
        self._cost_time = cost_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListSessionsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
